@@ -4,19 +4,20 @@
 """
 __docformat__ = "google"
 
-from pkg_resources import get_distribution, DistributionNotFound
+from pkg_resources import DistributionNotFound, get_distribution
 
-from turbo_broccoli.turbo_broccoli import (
-    TurboBroccoliDecoder,
-    TurboBroccoliEncoder,
-)
 from turbo_broccoli.environment import (
-    register_dataclass,
+    register_dataclass_type,
+    register_pytorch_module_type,
     set_artifact_path,
     set_keras_format,
     set_max_nbytes,
     set_pandas_format,
 )
+from turbo_broccoli.turbo_broccoli import (
+    TurboBroccoliDecoder,
+    TurboBroccoliEncoder,
+)
 
 try:
     __version__ = get_distribution("turbo-broccoli").version
